@@ -1,5 +1,6 @@
 import dict2sql.compiler_misc as comp
 import dict2sql.types as t
+from dict2sql.dialects.ansi import statement_delete
 from dict2sql.utils import Utils
 
 from . import statement_insert, statement_select, statement_update
@@ -10,6 +11,7 @@ class Statement(comp.BaseAlternativeParent):
         statement_select.SelectStatement,
         statement_insert.InsertStatement,
         statement_update.UpdateStatement,
+        statement_delete.DeleteStatement,
     ]
 
     @classmethod
